@@ -11,26 +11,26 @@ pwd_path = os.path.abspath(os.path.dirname(__file__))
 train_path = os.path.join(pwd_path, "data/train.txt")
 test_path = os.path.join(pwd_path, "data/test.txt")
 # run preprocess.py to segment train and test data
-train_seg_path = os.path.join(pwd_path, "data/train_seg_sample.txt")  # segment of train file
-test_seg_path = os.path.join(pwd_path, "data/test_seg_sample.txt")  # segment of test file
+train_seg_path = os.path.join(pwd_path, "../examples/train_seg_sample.txt")  # segment of train file
+test_seg_path = os.path.join(pwd_path, "../examples/test_seg_sample.txt")  # segment of test file
 
 col_sep = '\t'  # separate label and content of train data
 
 # one of "logistic_regression, random_forest, bayes, decision_tree, svm, knn, xgboost, xgboost_lr,
 # mlp, ensemble, stack, fasttext, cnn, rnn, han"
-model_type = "cnn"
+model_type = "logistic_regression"
 
 # feature type
 # classic text classification usage:  one of "tfidf_char, tfidf_word, tf_word",
 # deep text classification usage: cnn/rnn/fasttext is "vectorize"
-feature_type = 'vectorize'
+feature_type = 'tfidf_word'
 
-debug = False
+debug = True
 # default params
 sentence_symbol_path = os.path.join(pwd_path, 'data/sentence_symbol.txt')
-stop_words_path = os.path.join(pwd_path, 'data/stop_words.txt')
+stop_words_path = os.path.join(pwd_path, 'data/stopwords.txt')
 
-output_dir = os.path.join(pwd_path, "../output")  # output dir
+output_dir = os.path.join(pwd_path, "../examples")  # output dir
 if not os.path.exists(output_dir):
     os.makedirs(output_dir)
 word_vocab_path = os.path.join(output_dir, "vocab_{}_{}.txt".format(feature_type, model_type))  # vocab path
